@@ -36,47 +36,12 @@
   var ACESYNTAX = global.ACESYNTAX || {};
   var debugme = false; // debug flag, what else?... :p keep it false for production releases
   
-  $(document)
-    .ready(function()
-   {
-     $('.AceSyntax')
-       .each(function(index)
-        {
-          // do some initialization
-          var textarea = $(this);
-          var textareaid = 'ace_editor' + index;
-          var requesturi = getRequestUri();
-          var requestData1 = { html: 'top', current: index};
-          var requestData2 = { html: 'bottom', current: index};
-  
-          $.when( $.get(requesturi, requestData1), $.get(requesturi, requestData2)).done(function(toolbar, statusbar)
-          {
-            var tmpHTML = '';
-            tmpHTML += '<div class="ace-wrapper" id="' + textareaid + '_screen">';
-            tmpHTML += '<div class="ace-ui-container">';
-            tmpHTML += toolbar[0];
-            tmpHTML += '<div class="ace-container">';
-            tmpHTML += $(textarea).get(0).outerHTML;
-            tmpHTML += '</div>';
-            tmpHTML += statusbar[0];
-            tmpHTML += '</div>';
-            tmpHTML += '</div>';
-            $(textarea).replaceWith(tmpHTML);
-            
-            // run the app
-            ACESYNTAX.INIT.load();
-          });
-          
-        });
-   });
-  
-
-  // Run the app note: can't do it here anymore otherwise it is triggered too soon
-//  $(function()
-//  {
-//    ACESYNTAX.INIT.load();
-//    if(debugme){console.log('ACESYNTAX.INIT.load()!');}
-//  });
+  // Run the app
+  $(function()
+  {
+    ACESYNTAX.INIT.load();
+    if(debugme){console.log('ACESYNTAX.INIT.load()!');}
+  });
 
   ACESYNTAX.INIT = {
 
@@ -91,6 +56,8 @@
 
     }
   };
+  
+  
 
   /** =============================
    *  ACESYNTAX global functions
@@ -137,7 +104,7 @@
       config.set('modePath', config.get('basePath') + '/modes');
       config.set('workerPath', config.get('basePath') + '/workers');
 
-      if (window.ace) {
+      if(window.ace) {
         editors.each(function() {
 
           var $el = $(this),
@@ -154,7 +121,8 @@
           // create editor
           $('<div />').attr('id', $data.aceEditorId).addClass('ace_editor_content').insertBefore(textarea).html($(textarea).value);
           $(textarea).hide(); // hide textarea
-          
+  
+          if(debugme){console.log('editor start! ' + $data.aceEditorId);}
           editor = ace.edit($data.aceEditorId); // start ace
 
           // make editor working within tabs
@@ -361,16 +329,16 @@
          * @param {String} id
          */
         editorFullScreen : function(container, editor, id, textarea) {
-
+  
           var el = document.getElementById(container.attr('id')),
               nativeFullScreen = false,
-
+  
               /**
                * @description Updates container wrapper layout
                * @function layoutUpdate
                */
               layoutUpdate = function() {
-
+    
                 if (container.hasClass('fullscreen')) {
                   $(container).css({
                                      position : 'static'
